@@ -1,4 +1,4 @@
-## Copyright 2012-2013 Sebastian Gibb
+## Copyright 2012-2014 Sebastian Gibb
 ## <mail@sebastiangibb.de>
 ##
 ## This file is part of MALDIquant for R and related languages.
@@ -25,14 +25,15 @@
 ##             MassPeaks objects should be aligned
 ##  tolerance: double, maximal deviation of a peak position to be
 ##             considered as same peak
-##  warpingFunction: function, used to create warping function
+##  method: choose type of base warping function
 ##  plot: logical, plots warping function
 ##
 ## returns:
 ##  a list of warping functions
 ##
 determineWarpingFunctions <- function(l, reference, tolerance=0.002,
-                                      warpingFunction=.warpingFunctionLowess,
+                                      method=c("lowess", "linear", "quadratic",
+                                               "cubic"),
                                       plot=FALSE, plotInteractive=FALSE, ...) {
 
   ## test arguments
@@ -40,7 +41,25 @@ determineWarpingFunctions <- function(l, reference, tolerance=0.002,
     stop(sQuote("l"), " is no list of MALDIquant::MassPeaks objects!")
   }
 
-  warpingFunction <- match.fun(warpingFunction)
+  method <- match.arg(method)
+
+  warpingFunction <- switch(method,
+    "lowess" = {
+      .warpingFunctionLowess
+    },
+    "linear" = {
+      .warpingFunctionLinear
+    },
+    "quadratic" = {
+      .warpingFunctionQuadratic
+    },
+    "cubic" = {
+      .warpingFunctionCubic
+    },
+    {
+      stop("Unknown ", sQuote("method"), ".")
+    }
+  )
 
   optArgs <- list(...)
 
@@ -59,6 +78,13 @@ determineWarpingFunctions <- function(l, reference, tolerance=0.002,
     stop("Reference MassPeaks object contains no peaks!")
   }
 
+  if (length(reference) < 10) {
+    warning("Reference MassPeaks object contains very few peaks (n == ",
+            length(reference), "). The warping could be instable. ",
+            "Consider to reduce ", sQuote("minFrequency"),
+            " or/and to increase ", sQuote("tolerance"), ".")
+  }
+
   ## fetch plot.default arguments (debug plot)
   if (plot) {
     plotNames <- c("xlim", "ylim", "xlab", "ylab", "type", "lwd", "col",
@@ -79,7 +105,7 @@ determineWarpingFunctions <- function(l, reference, tolerance=0.002,
   intensities <- .unlist(lapply(tmpPeakList, function(x)x@intensity))
 
   ## store original mass sample number/id
-  samples <- .unlist(lapply(1:length(tmpPeakList), function(x) {
+  samples <- .unlist(lapply(1L:length(tmpPeakList), function(x) {
                 return(rep(x, length(tmpPeakList[[x]])))
   }))
 
@@ -97,12 +123,12 @@ determineWarpingFunctions <- function(l, reference, tolerance=0.002,
                           grouper=.grouperRelaxedHighestAtReference)
 
   ## group mass/intensities by sample ids
-  lIdx <- tapply(X=1:length(binnedMass), INDEX=samples, FUN=function(x) {
+  lIdx <- tapply(X=1L:length(binnedMass), INDEX=samples, FUN=function(x) {
       return(x)
   })
 
   ## calculate differences
-  binnedMass[binnedMass == 0] <- NA
+  binnedMass[binnedMass == 0L] <- NA
   d <- binnedMass-mass
 
   ## each function which determines a warping function uses these 3 arguments
@@ -112,7 +138,7 @@ determineWarpingFunctions <- function(l, reference, tolerance=0.002,
   }
 
   ## determine warping functions
-  warpingFunctions <- lapply(lIdx[-1], function(i) {
+  warpingFunctions <- lapply(lIdx[-1L], function(i) {
     ## fetch changed mass == aligned peaks
     notNA <- !is.na(binnedMass[i])
 
@@ -120,7 +146,7 @@ determineWarpingFunctions <- function(l, reference, tolerance=0.002,
     arguments$d <- d[i][notNA]  ## difference to reference
 
     if (!length(arguments$x)) {
-      stop("Could not match any peak in spectrum ", samples[i[1]]-1,
+      stop("Could not match any peak in spectrum ", samples[i[1L]]-1L,
            " to a reference peak.")
     }
 
@@ -135,7 +161,7 @@ determineWarpingFunctions <- function(l, reference, tolerance=0.002,
   ## debug plot
   if (plot) {
     ## non interactive device (pdf, png, ...) available?
-    isNonInteractivePlot <- dev.cur() != 1 && !dev.interactive()
+    isNonInteractivePlot <- dev.cur() != 1L && !dev.interactive()
 
     if (!isNonInteractivePlot && !plotInteractive) {
       warning(sQuote("plot"), " is ", sQuote("TRUE"),
@@ -155,8 +181,8 @@ determineWarpingFunctions <- function(l, reference, tolerance=0.002,
                              xlab="mass",
                              ylab="difference",
                              type="p",
-                             lwd=1,
-                             col=1,
+                             lwd=1L,
+                             col=1L,
                              cex.main=0.8,
                              cex.sub=0.75,
                              col.sub="#808080")
@@ -164,7 +190,7 @@ determineWarpingFunctions <- function(l, reference, tolerance=0.002,
     plotArgs <- modifyList(plotArgsDefaults, givenPlotArgs)
 
     nReference <- length(reference)
-    x <- plotArgs$xlim[1]:plotArgs$xlim[2]
+    x <- plotArgs$xlim[1L]:plotArgs$xlim[2L]
 
     ## workaround to avoid error:
     ## Error in l[[i]] : this S4 class is not subsettable
@@ -174,7 +200,7 @@ determineWarpingFunctions <- function(l, reference, tolerance=0.002,
 
     for (i in seq(along=l)) {
       ## fetch changed mass == aligned peaks
-      notNA <- !is.na(binnedMass[lIdx[[i+1]]])
+      notNA <- !is.na(binnedMass[lIdx[[i+1L]]])
 
       if (is.null(givenPlotArgs$main)) {
         plotArgs$main <- paste0("sample ", i, " vs reference\n",
@@ -188,7 +214,7 @@ determineWarpingFunctions <- function(l, reference, tolerance=0.002,
 
       ## plot reference vs sample
       plotArgs$x <- l[[i]]@mass[notNA]
-      plotArgs$y <- d[lIdx[[i+1]]][notNA]
+      plotArgs$y <- d[lIdx[[i+1L]]][notNA]
       do.call(plot.default, plotArgs)
 
       ## draw warping function
