@@ -19,9 +19,19 @@
 ## AbstractMassObject
 .validAbstractMassObject <- function(object) {
   if (length(object@mass) != length(object@intensity)) {
-    return(paste("Lengths of mass (", length(object@mass),
-                 ") and intensity (", length(object@intensity),
-                 ") have to be equal.", sep=""))
+    return(paste0("Lengths of mass (", length(object@mass),
+                  ") and intensity (", length(object@intensity),
+                  ") have to be equal."))
+  }
+  if (is.numeric(object@mass) &&
+      length(object@mass) &&
+      any(object@mass < 0L)) {
+    warning("Negative mass values found.")
+  }
+  if (is.numeric(object@intensity) &&
+      !isEmpty(object) &&
+      any(object@intensity < 0L)) {
+    warning("Negative intensity values found.")
   }
   return(TRUE)
 }
@@ -30,9 +40,9 @@ setValidity("AbstractMassObject", method=.validAbstractMassObject)
 
 .validMassPeaks <- function(object) {
   if (length(object@intensity) != length(object@snr)) {
-    return(paste("Lengths of intensity (", length(object@intensity),
-                 ") and snr(", length(object@snr),
-                 ") have to be equal.", sep=""))
+    return(paste0("Lengths of intensity (", length(object@intensity),
+                  ") and snr(", length(object@snr),
+                  ") have to be equal."))
   }
   return(.validAbstractMassObject(object))
 }
